@@ -34,7 +34,7 @@
 #include <QTime>
 #include <QStack>
 
-class KgDifficultyLevel;
+class KGameDifficultyLevel;
 
 namespace Knights {
 
@@ -122,7 +122,7 @@ private:
 	Protocol* local();
 
 public Q_SLOTS:
-	void levelChanged(const KgDifficultyLevel*);
+	void levelChanged(const KGameDifficultyLevel*);
 
 	void moveByExternalControl(const Move&);
 	void moveByBoard(const Move&);
@@ -136,6 +136,10 @@ public Q_SLOTS:
 	void undo();
 	void redo();
 
+	void offerDraw();
+	void adjourn();
+	void abort();
+
 	void loadGameHistoryFrom(const QString& filename);
 	void saveGameHistoryAs(const QString& filename);
 
@@ -143,9 +147,6 @@ private Q_SLOTS:
 	void moveByProtocol(const Move&);
 	void protocolInitSuccesful();
 	void gameOver(Color);
-	void offerDraw();
-	void adjourn();
-	void abort();
 	void setTimeRunning(bool);
 	void sendPendingMove();
 
